@@ -210,6 +210,9 @@ class GitJiraConventionalCz(BaseCommitizen):
         if footer:
             footer = f"\n\n{footer}"
 
+        if scope is None:
+            scope = ""
+
         message = f"{prefix}{scope}: {subject}{body}{footer}"
 
         return message
